@@ -16,14 +16,12 @@ import (
 	syftPkg "github.com/anchore/syft/syft/pkg"
 )
 
-func TestGetByDistro(t *testing.T) {
+func Test_GetByDistro(t *testing.T) {
 	provider, err := NewVulnerabilityProvider(newMockStore())
 	require.NoError(t, err)
 
 	d, err := distro.New(distro.Debian, "8", "")
-	if err != nil {
-		t.Fatalf("failed to create distro: %+v", err)
-	}
+	require.NoError(t, err)
 
 	p := pkg.Package{
 		ID:   pkg.ID(uuid.NewString()),
@@ -31,9 +29,7 @@ func TestGetByDistro(t *testing.T) {
 	}
 
 	actual, err := provider.GetByDistro(d, p)
-	if err != nil {
-		t.Fatalf("failed to get by distro: %+v", err)
-	}
+	require.NoError(t, err)
 
 	expected := []vulnerability.Vulnerability{
 		{
@@ -63,7 +59,7 @@ func TestGetByDistro(t *testing.T) {
 	}
 }
 
-func TestGetByDistro_nilDistro(t *testing.T) {
+func Test_GetByDistro_nilDistro(t *testing.T) {
 	provider, err := NewVulnerabilityProvider(newMockStore())
 	require.NoError(t, err)
 
@@ -85,7 +81,7 @@ func must(c syftPkg.CPE, e error) syftPkg.CPE {
 	return c
 }
 
-func TestGetByCPE(t *testing.T) {
+func Test_GetByCPE(t *testing.T) {
 
 	tests := []struct {
 		name     string
@@ -183,3 +179,30 @@ func TestGetByCPE(t *testing.T) {
 	}
 
 }
+
+func Test_Get(t *testing.T) {
+	provider, err := NewVulnerabilityProvider(newMockStore())
+	require.NoError(t, err)
+
+	actual, err := provider.Get("CVE-2014-fake-1", "debian:distro:debian:8")
+	require.NoError(t, err)
+
+	expected := []vulnerability.Vulnerability{
+		{
+			Constraint:        version.MustGetConstraint("< 2014.1.3-6", version.DebFormat),
+			ID:                "CVE-2014-fake-1",
+			Namespace:         "debian:distro:debian:8",
+			PackageQualifiers: []qualifier.Qualifier{},
+			CPEs:              []syftPkg.CPE{},
+			Advisories:        []vulnerability.Advisory{},
+		},
+	}
+
+	require.Len(t, actual, len(expected))
+
+	for idx, vuln := range actual {
+		for _, d := range deep.Equal(expected[idx], vuln) {
+			t.Errorf("diff: %+v", d)
+		}
+	}
+}
