@@ -14,6 +14,11 @@ type mockProvider struct {
 	data map[string]map[string][]vulnerability.Vulnerability
 }
 
+func (pr *mockProvider) Get(id, namespace string) ([]vulnerability.Vulnerability, error) {
+	//TODO implement me
+	panic("implement me")
+}
+
 func newMockProvider() *mockProvider {
 	pr := mockProvider{
 		data: make(map[string]map[string][]vulnerability.Vulnerability),
