@@ -21,12 +21,14 @@ func syftProvider(userInput string, config ProviderConfig) ([]Package, Context,
 	}
 	defer cleanup()
 
-	catalog, _, theDistro, err := syft.CatalogPackages(src, config.CatalogingOptions)
+	catalog, relationships, theDistro, err := syft.CatalogPackages(src, config.CatalogingOptions)
 	if err != nil {
 		return nil, Context{}, err
 	}
 
-	return FromCatalog(catalog, config), Context{
+	catalog = RemoveBinaryPackagesByOverlap(catalog, relationships)
+
+	return FromCatalog(catalog, config.SynthesisConfig), Context{
 		Source: &src.Metadata,
 		Distro: theDistro,
 	}, nil
